@@ -1,9 +1,9 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.54 2005/03/07 22:02:52 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/api.lisp,v 1.59 2005/06/26 22:01:16 edi Exp $
 
 ;;; The external API for creating and using scanners.
 
-;;; Copyright (c) 2002-2004, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2005, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -49,12 +49,7 @@ NIL the function is allowed to destructively modify its first argument
                                                       single-line-mode
                                                       extended-mode
                                                       destructive)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (ignore destructive))
   ;; parse the string into a parse-tree and then call CREATE-SCANNER
   ;; again
@@ -77,12 +72,7 @@ NIL the function is allowed to destructively modify its first argument
                                                    single-line-mode
                                                    extended-mode
                                                    destructive)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (ignore destructive))
   (when (or case-insensitive-mode multi-line-mode single-line-mode extended-mode)
     (signal-ppcre-invocation-error
@@ -95,12 +85,7 @@ NIL the function is allowed to destructively modify its first argument
                                                single-line-mode
                                                extended-mode
                                                destructive)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (when extended-mode
     (signal-ppcre-invocation-error
      "Extended mode doesn't make sense in parse trees."))
@@ -233,12 +218,7 @@ be coerced to a simple string if it isn't one already."))
 (defmethod scan ((regex-string string) target-string
                                        &key (start 0)
                                             (end (length target-string)))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   ;; note that the scanners are optimized for simple strings so we
   ;; have to coerce TARGET-STRING into one if it isn't already
   (funcall (create-scanner regex-string)
@@ -249,12 +229,7 @@ be coerced to a simple string if it isn't one already."))
 (defmethod scan ((scanner function) target-string
                                     &key (start 0)
                                          (end (length target-string)))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (funcall scanner
            (maybe-coerce-to-simple-string target-string)
            start end))
@@ -263,12 +238,7 @@ be coerced to a simple string if it isn't one already."))
 (defmethod scan ((parse-tree t) target-string
                                 &key (start 0)
                                      (end (length target-string)))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (funcall (create-scanner parse-tree)
            (maybe-coerce-to-simple-string target-string)
            start end))
@@ -300,6 +270,7 @@ be coerced to a simple string if it isn't one already."))
                               (aref reg-ends i) end))
                (values (car match) (cdr match) reg-starts reg-ends))))))
 
+#-:cormanlisp
 (define-compiler-macro scan (&whole form &environment env regex target-string &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
   (cond ((constantp regex env)
@@ -311,12 +282,7 @@ be coerced to a simple string if it isn't one already."))
 (defun scan-to-strings (regex target-string &key (start 0)
                                                  (end (length target-string))
                                                  sharedp)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Like SCAN but returns substrings of TARGET-STRING instead of
 positions, i.e. this function returns two values on success: the whole
 match as a string plus an array of substrings (or NILs) corresponding
@@ -338,6 +304,7 @@ structure with TARGET-STRING."
                    reg-starts
                    reg-ends)))))
 
+#-:cormanlisp
 (define-compiler-macro scan-to-strings
     (&whole form &environment env regex target-string &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
@@ -538,12 +505,7 @@ share structure with TARGET-STRING. BODY may start with declarations."
 (defun all-matches (regex target-string
                           &key (start 0)
                                (end (length target-string)))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Returns a list containing the start and end positions of all
 matches of REGEX against TARGET-STRING, i.e. if there are N matches
 the list contains (* 2 N) elements. If REGEX matches an empty string
@@ -556,6 +518,7 @@ the scan is continued one position behind this match."
       (push match-start result-list)
       (push match-end result-list))))
 
+#-:cormanlisp
 (define-compiler-macro all-matches (&whole form &environment env regex &rest rest)
    "Make sure that constant forms are compiled into scanners at
 compile time."
@@ -569,12 +532,7 @@ compile time."
                                      &key (start 0)
                                           (end (length target-string))
                                           sharedp)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Returns a list containing all substrings of TARGET-STRING which
 match REGEX. If REGEX matches an empty string the scan is continued
 one position behind this match. If SHAREDP is true, the substrings may
@@ -584,6 +542,7 @@ share structure with TARGET-STRING."
                                   :start start :end end :sharedp sharedp)
       (push match result-list))))
 
+#-:cormanlisp
 (define-compiler-macro all-matches-as-strings (&whole form &environment env regex &rest rest)
    "Make sure that constant forms are compiled into scanners at
 compile time."
@@ -601,12 +560,7 @@ compile time."
                          with-registers-p
                          omit-unmatched-p
                          sharedp)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Matches REGEX against TARGET-STRING as often as possible and
 returns a list of the substrings between the matches. If
 WITH-REGISTERS-P is true, substrings corresponding to matched
@@ -670,6 +624,7 @@ TARGET-STRING."
                               target-string this-start this-end)
                      nil)))))
 
+#-:cormanlisp
 (define-compiler-macro split (&whole form &environment env regex target-string &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
   (cond ((constantp regex env)
@@ -679,12 +634,7 @@ TARGET-STRING."
         (t form)))
 
 (defun string-case-modifier (str from to start end)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (type fixnum from to start end))
   "Checks whether all words in STR between FROM and TO are upcased,
 downcased or capitalized and returns a function which applies a
@@ -749,19 +699,18 @@ that (<= START FROM TO END)."
 
 ;; first create a scanner to identify the special parts of the
 ;; replacement string (eat your own dog food...)
+
+(defgeneric build-replacement-template (replacement-string)
+  (declare #.*standard-optimize-settings*)
+  (:documentation "Converts a replacement string for REGEX-REPLACE or
+REGEX-REPLACE-ALL into a replacement template which is an
+S-expression."))
+
 #-:cormanlisp
 (let* ((*use-bmh-matchers* nil)
        (reg-scanner (create-scanner "\\\\(?:\\\\|\\{\\d+\\}|\\d+|&|`|')")))
   (defmethod build-replacement-template ((replacement-string string))
-    (declare (optimize speed
-                       (safety 0)
-                       (space 0)
-                       (debug 1)
-                       (compilation-speed 0)
-                       #+:lispworks (hcl:fixnum-safety 0)))
-    "Converts a replacement string for REGEX-REPLACE or
-REGEX-REPLACE-ALL into a replacement template which is an
-S-expression."
+    (declare #.*standard-optimize-settings*)
     (let ((from 0)
           ;; COLLECTOR will hold the (reversed) template
           (collector '()))
@@ -817,12 +766,7 @@ S-expression."
 (let* ((*use-bmh-matchers* nil)
        (reg-scanner (create-scanner "\\\\(?:\\\\|\\{\\d+\\}|\\d+|&|`|')")))
   (defun build-replacement-template (replacement)
-    (declare (optimize speed
-                       (safety 0)
-                       (space 0)
-                       (debug 1)
-                       (compilation-speed 0)
-                       #+:lispworks (hcl:fixnum-safety 0)))
+    (declare #.*standard-optimize-settings*)
     (typecase replacement
       (string
         (let ((from 0)
@@ -873,12 +817,7 @@ S-expression."
                           match-start match-end
                           reg-starts reg-ends
                           simple-calls)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Accepts a replacement template and the current values from the
 matching process in REGEX-REPLACE or REGEX-REPLACE-ALL and returns the
 corresponding template."
@@ -964,12 +903,7 @@ corresponding template."
 
 (defun replace-aux (target-string replacement pos-list reg-list
                                   start end preserve-case simple-calls)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Auxiliary function used by REGEX-REPLACE and
 REGEX-REPLACE-ALL. POS-LIST contains a list with the start and end
 positions of all matches while REG-LIST contains a list of arrays
@@ -1013,12 +947,7 @@ representing the corresponding register start and end positions."
                             (end (length target-string))
                             preserve-case
                             simple-calls)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Try to match TARGET-STRING between START and END against REGEX and
 replace the first match with REPLACEMENT.
 
@@ -1054,6 +983,7 @@ match."
                    start end preserve-case simple-calls)
       (subseq target-string start end))))
 
+#-:cormanlisp
 (define-compiler-macro regex-replace
     (&whole form &environment env regex target-string replacement &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
@@ -1068,12 +998,7 @@ match."
                                      (end (length target-string))
                                      preserve-case
                                      simple-calls)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Try to match TARGET-STRING between START and END against REGEX and
 replace all matches with REPLACEMENT.
 
@@ -1116,6 +1041,7 @@ match."
                    start end preserve-case simple-calls)
       (subseq target-string start end))))
 
+#-:cormanlisp
 (define-compiler-macro regex-replace-all
     (&whole form &environment env regex target-string replacement &rest rest)
   "Make sure that constant forms are compiled into scanners at compile time."
@@ -1184,12 +1110,7 @@ scanner, a case-insensitive scanner is used."
         ,return-form))))
 
 (defun regex-apropos-list (regex &optional packages &key (case-insensitive t))
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Similar to the standard function APROPOS-LIST but returns a list of
 all symbols which match the regular expression REGEX. If
 CASE-INSENSITIVE is true and REGEX isn't already a scanner, a
@@ -1201,12 +1122,7 @@ case-insensitive scanner is used."
 (defun print-symbol-info (symbol)
   "Auxiliary function used by REGEX-APROPOS. Tries to print some
 meaningful information about a symbol."
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (handler-case
     (let ((output-list '()))
       (cond ((special-operator-p symbol)
@@ -1251,12 +1167,7 @@ meaningful information about a symbol."
 symbols which match the regular expression REGEX. If CASE-INSENSITIVE
 is true and REGEX isn't already a scanner, a case-insensitive scanner
 is used."
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (regex-apropos-aux (regex packages case-insensitive)
     (print-symbol-info symbol))
   (values))
