@@ -1,11 +1,11 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/convert.lisp,v 1.20 2005/03/07 22:02:53 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/convert.lisp,v 1.22 2005/04/01 21:29:09 edi Exp $
 
 ;;; Here the parse tree is converted into its internal representation
 ;;; using REGEX objects.  At the same time some optimizations are
 ;;; already applied.
 
-;;; Copyright (c) 2002-2004, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2005, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -50,12 +50,7 @@
   `(third ,flags))
 
 (defun set-flag (token)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (special flags))
   "Reads a flag token and sets or unsets the corresponding entry in
 the special FLAGS list."
@@ -76,12 +71,7 @@ the special FLAGS list."
       (signal-ppcre-syntax-error "Unknown flag token ~A" token))))
 
 (defun add-range-to-hash (hash from to)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (special flags))
   "Adds all characters from character FROM to character TO (inclusive)
 to the char class hash HASH. Does the right thing with respect to
@@ -102,12 +92,7 @@ case-(in)sensitivity as specified by the special variable FLAGS."
     hash))
 
 (defun convert-char-class-to-hash (list)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Combines all items in LIST into one char class hash and returns it.
 Items can be single characters, character ranges like \(:RANGE #\\A
 #\\E), or special character classes like :DIGIT-CLASS. Does the right
@@ -157,12 +142,7 @@ special variable FLAGS."
                                min-len
                                length
                                reg-seen)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (type fixnum minimum)
            (type (or fixnum null) maximum))
   "Splits a REPETITION object into a constant and a varying part if
@@ -231,12 +211,7 @@ the same name."
 ;; regex at the start (perhaps modulo #\Newline).
 
 (defun maybe-accumulate (str)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (special accumulate-start-p starts-with))
   (declare (ftype (function (t) fixnum) len))
   "Accumulate STR into the special variable STARTS-WITH if
@@ -291,12 +266,7 @@ NIL or a STR object of the same case mode. Always returns NIL."
   nil)
 
 (defun convert-aux (parse-tree)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (special flags reg-num accumulate-start-p starts-with max-back-ref))
   "Converts the parse tree PARSE-TREE into a REGEX object and returns it.
 
@@ -756,12 +726,7 @@ Will also
                                             parse-tree))))))))
 
 (defun convert (parse-tree)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Converts the parse tree PARSE-TREE into an equivalent REGEX object
 and returns three values: the REGEX object, the number of registers
 seen and an object the regex starts with which is either a STR object
