@@ -1,10 +1,10 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/optimize.lisp,v 1.23 2005/03/07 22:02:53 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/optimize.lisp,v 1.26 2005/04/13 15:35:57 edi Exp $
 
 ;;; This file contains optimizations which can be applied to converted
 ;;; parse trees.
 
-;;; Copyright (c) 2002-2004, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2005, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -33,12 +33,7 @@
 (in-package #:cl-ppcre)
 
 (defgeneric flatten (regex)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (:documentation "Merges adjacent sequences and alternations, i.e. it
 transforms #<SEQ #<STR \"a\"> #<SEQ #<STR \"b\"> #<STR \"c\">>> to
 #<SEQ #<STR \"a\"> #<STR \"b\"> #<STR \"c\">>. This is a destructive
@@ -129,12 +124,7 @@ operation on REGEX."))
       regex)))
 
 (defgeneric gather-strings (regex)
-    (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+    (declare #.*standard-optimize-settings*)
   (:documentation "Collects adjacent strings or characters into one
 string provided they have the same case mode. This is a destructive
 operation on REGEX."))
@@ -293,12 +283,7 @@ operation on REGEX."))
 ;; Note that START-ANCHORED-P will be called after FLATTEN and GATHER-STRINGS.
 
 (defgeneric start-anchored-p (regex &optional in-seq-p)
-    (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+    (declare #.*standard-optimize-settings*)
   (:documentation "Returns T if REGEX starts with a \"real\" start
 anchor, i.e. one that's not in multi-line mode, NIL otherwise. If
 IN-SEQ-P is true the function will return :ZERO-LENGTH if REGEX is a
@@ -367,12 +352,7 @@ zero-length assertion."))
 ;; Note that END-STRING-AUX will be called after FLATTEN and GATHER-STRINGS.
 
 (defgeneric end-string-aux (regex &optional old-case-insensitive-p)
-    (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+    (declare #.*standard-optimize-settings*)
   (:documentation "Returns the constant string (if it exists) REGEX
 ends with wrapped into a STR object, otherwise NIL.
 OLD-CASE-INSENSITIVE-P is the CASE-INSENSITIVE-P slot of the last STR
@@ -494,16 +474,14 @@ function called by END-STRIN.)"))
       ;; REPETITION, FILTER)
       nil)))
 
+(defgeneric end-string (regex)
+  (declare #.*standard-optimize-settings*)
+  (:documentation "Returns the constant string (if it exists) REGEX ends with wrapped
+into a STR object, otherwise NIL."))
+
 (defmethod end-string ((regex regex))
   (declare (special end-string-offset))
-    (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
-  "Returns the constant string (if it exists) REGEX ends with wrapped
-into a STR object, otherwise NIL."
+    (declare #.*standard-optimize-settings*)
   ;; LAST-STR points to the last STR object (seen from the end) that's
   ;; part of END-STRING; CONTINUEP is set to T if we stop collecting
   ;; in the middle of a SEQ
@@ -521,12 +499,7 @@ into a STR object, otherwise NIL."
               end-string-offset (offset last-str))))))
 
 (defgeneric compute-min-rest (regex current-min-rest)
-    (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+    (declare #.*standard-optimize-settings*)
   (:documentation "Returns the minimal length of REGEX plus
 CURRENT-MIN-REST. This is similar to REGEX-MIN-LENGTH except that it
 recurses down into REGEX and sets the MIN-REST slots of REPETITION
