@@ -1,10 +1,10 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/scanner.lisp,v 1.23 2005/03/07 22:02:53 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/scanner.lisp,v 1.25 2005/04/01 21:29:10 edi Exp $
 
 ;;; Here the scanner for the actual regex as well as utility scanners
 ;;; for the constant start and end strings are created.
 
-;;; Copyright (c) 2002-2004, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2005, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -53,12 +53,7 @@
                                  (return-from bmh-matcher (1+ i)))))))))
 
 (defun create-bmh-matcher (pattern case-insensitive-p)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Returns a Boyer-Moore-Horspool matcher which searches the (special)
 simple-string *STRING* for the first occurence of the substring
 PATTERN. The search starts at the position START-POS within *STRING*
@@ -103,12 +98,7 @@ instead. (BMH matchers are faster but need much more space.)"
             thereis (and (,char-compare (schar *string* i) chr) i)))))
 
 (defun create-char-searcher (chr case-insensitive-p)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Returns a function which searches the (special) simple-string
 *STRING* for the first occurence of the character CHR. The search
 starts at the position START-POS within *STRING* and stops before
@@ -121,12 +111,7 @@ case-insensitive or not."
 (declaim (inline newline-skipper))
 
 (defun newline-skipper (start-pos)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (type fixnum start-pos))
   "Find the next occurence of a character in *STRING* which is behind
 a #\Newline."
@@ -335,12 +320,7 @@ ADVANCE-FN. This is a utility macro used by CREATE-SCANNER-AUX."
                            rep-num
                            zero-length-num
                            reg-num)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   (declare (type fixnum min-len zero-length-num rep-num reg-num))
   "Auxiliary function to create and return a scanner \(which is
 actually a closure). Used by CREATE-SCANNER."
@@ -523,4 +503,4 @@ actually a closure). Used by CREATE-SCANNER."
         ;; expression to optimize so we just return POS
         (insert-advance-fn
           (advance-fn (pos)
-            pos))))))
\ No newline at end of file
+            pos))))))
