@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-PPCRE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-ppcre/util.lisp,v 1.28 2005/03/07 22:02:53 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-ppcre/util.lisp,v 1.30 2005/04/01 21:29:10 edi Exp $
 
 ;;; Utility functions and constants dealing with the hash-tables
 ;;; we use to encode character classes
@@ -7,7 +7,7 @@
 ;;; Hash-tables are treated like sets, i.e. a character C is a member of the
 ;;; hash-table H iff (GETHASH C H) is true.
 
-;;; Copyright (c) 2002-2004, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2002-2005, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -101,7 +101,7 @@ the full Unicode support of LW, ACL, or CLISP.")
   (declaim (type fixnum *regex-char-code-limit*))
   
   (defun make-char-hash (test)
-    (declare (optimize speed space))
+    (declare #.*special-optimize-settings*)
     "Returns a hash-table of all characters satisfying test."
     (loop with hash = (make-hash-table)
           for c of-type fixnum from 0 below char-code-limit
@@ -113,12 +113,7 @@ the full Unicode support of LW, ACL, or CLISP.")
   (declaim (inline word-char-p))
   
   (defun word-char-p (chr)
-    (declare (optimize speed
-                       (safety 0)
-                       (space 0)
-                       (debug 1)
-                       (compilation-speed 0)
-                       #+:lispworks (hcl:fixnum-safety 0)))
+    (declare #.*standard-optimize-settings*)
     "Tests whether a character is a \"word\" character.
 In the ASCII charset this is equivalent to a-z, A-Z, 0-9, or _,
 i.e. the same as Perl's [\\w]."
@@ -134,7 +129,7 @@ i.e. the same as Perl's [\\w]."
 Same as Perl's [\\s]."))
 
   (defun whitespacep (chr)
-    (declare (optimize speed space))
+    (declare #.*special-optimize-settings*)
     "Tests whether a character is whitespace,
 i.e. whether it would match [\\s] in Perl."
     (find chr +whitespace-char-string+ :test #'char=)))
@@ -158,12 +153,7 @@ i.e. whether it would match [\\s] in Perl."
     "Hash-table containing all whitespace characters."))
 
 (defun merge-hash (hash1 hash2)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Returns the \"sum\" of two hashes. This is a destructive operation
 on HASH1."
   (cond ((> (hash-table-count hash2)
@@ -180,12 +170,7 @@ on HASH1."
   hash1)
 
 (defun merge-inverted-hash (hash1 hash2)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Returns the \"sum\" of HASH1 and the \"inverse\" of HASH2. This is
 a destructive operation on HASH1."
   (loop for c of-type fixnum from 0 below *regex-char-code-limit*
@@ -195,12 +180,7 @@ a destructive operation on HASH1."
   hash1)
 
 (defun create-ranges-from-hash (hash &key downcasep)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Tries to identify up to three intervals (with respect to CHAR<)
 which together comprise HASH. Returns NIL if this is not possible.
 If DOWNCASEP is true it will treat the hash-table as if it represents
@@ -289,12 +269,7 @@ entries) out of the short form of VAR-LIST."
           collect (list '(function identity) element)))
 
 (defun string-list-to-simple-string (string-list)
-  (declare (optimize speed
-                     (safety 0)
-                     (space 0)
-                     (debug 1)
-                     (compilation-speed 0)
-                     #+:lispworks (hcl:fixnum-safety 0)))
+  (declare #.*standard-optimize-settings*)
   "Concatenates a list of strings to one simple-string."
   ;; this function provided by JP Massar; note that we can't use APPLY
   ;; with CONCATENATE here because of CALL-ARGUMENTS-LIMIT
